==> pyabr-0.0.9-py3-none-any.whl: packs/baran/code/apps/barge/barge.py <==
from PyQt5 import QtWidgets, uic, QtGui,QtCore
import sys, importlib
from libabr import core,app as apps,res, file
from libnam import files
import app, importlib

class MainApp(QtWidgets.QMainWindow):

    def __init__(self,args):
        super(MainApp, self).__init__()

        self.Backend = args[0]
        self.Env = args[1]
        self.Desktop = args[2]
        self.Widget = args[3]

        self.Widget.resize (700,500)

        self.Widget.setWindowTitle("Untitled - Barge")

        ## Set Icon ##
        self.Widget.setWindowIcon (QtGui.QIcon(res.get('@logo/barge')))
        ## Text Edit Configure ##

        ## Text Box ##
        self.teBox = QtWidgets.QTextEdit()
        self.statusbar = QtWidgets.QStatusBar()
        self.setCentralWidget(self.teBox)
        self.setStatusBar(self.statusbar)

        ## Menu Bar ##
        self.menubar = QtWidgets.QMenuBar()
        self.setMenuBar(self.menubar)

        # Menus #
        self.menu_file = self.menubar.addMenu(res.get('@string/menu_file'))
        self.menu_view = self.menubar.addMenu(res.get('@string/menu_view'))
        self.menu_help = self.menubar.addMenu(res.get('@string/menu_help'))
        self.menu_themes = self.menu_view.addMenu(res.get('@string/menu_themes'))

        # Actions #
        self.action_new = self.menu_file.addAction(res.get('@string/action_new'))
        self.action_new_page = self.menu_file.addAction(res.get('@string/action_new_page'))
        self.action_open = self.menu_file.addAction(res.get('@string/action_open'))
        self.action_save = self.menu_file.addAction(res.get('@string/action_save'))
        self.action_save_as = self.menu_file.addAction(res.get('@string/action_save_as'))
        self.action_exit = self.menu_file.addAction(res.get('@string/action_exit'))
        self.action_font = self.menu_view.addAction(res.get('@string/action_font'))
        self.action_bgcolor = self.menu_view.addAction(res.get('@string/action_bgcolor'))
        self.action_fgcolor = self.menu_view.addAction(res.get('@string/action_fgcolor'))

        # Do actions ##
        self.action_new.triggered.connect(self.new_act)
        self.action_new_page.triggered.connect(self.new_page_act)
        self.action_open.triggered.connect(self.open_act)
        self.action_save.triggered.connect(self.save_act)
        self.action_save_as.triggered.connect(self.save_as_act)
        self.action_font.triggered.connect(self.font_act)
        self.action_bgcolor.triggered.connect(self.bgcolor_act)
        self.action_fgcolor.triggered.connect(self.fgcolor_act)

        ## Set Default theme ##
        self.teBox.setFont(QtGui.QFont('Tahoma',16))
        self.bgcolor = '#FFFFFF'
        self.fgcolor = '#000000'
        self.teBox.setStyleSheet('background-color: ' + self.bgcolor + ";color: " + self.fgcolor)

    def new_act (self):
        s = QtWidgets.QColorDialog()
        self.Desktop.Dialog(s)
        self.teBox.clear()
        self.Widget.setWindowTitle(res.get("@string/new_barge"))


    def new_page_act (self):
        import barge
        importlib.reload(barge)
        self.Desktop.Run(barge)

    def open_act (self):
        opf = QtWidgets.QFileDialog().getOpenFileName()
        filename = opf[0]

        self.Widget.setWindowTitle(filename)

        file = open(filename, "rb")
        check_bin = str(file.read())
        file.close()
        if check_bin.__contains__("\\x00"):
            strv = check_bin
        else:
            file = open (filename,'r')
            strv = file.read()
            file.close()

        self.teBox.setText(strv)

    def save_act (self):
        if self.Widget.windowTitle()==res.get('@string/new_barge'):
            opf = QtWidgets.QFileDialog()
            filename = opf.getSaveFileName()[0]

            self.Desktop.Dialog(opf)

            file = open(filename, 'w')
            file.write (self.teBox.toPlainText()) # https://stackoverflow.com/questions/24035660/how-to-read-from-qtextedit-in-python
            file.close()

            self.Widget.setWindowTitle(filename)
        else:
            file = open(self.Widget.windowTitle(), 'w')
            file.write(self.teBox.toPlainText()) # https://stackoverflow.com/questions/24035660/how-to-read-from-qtextedit-in-python
            file.close()

    def save_as_act (self):
        opf = QtWidgets.QFileDialog()
        opf.setOptions(QtWidgets.QFileDialog.DontUseNativeDialog)
        filename = opf.getSaveFileName()[0]

        self.Desktop.Dialog(opf)

        file = open(filename, 'w')
        file.write(
            self.teBox.toPlainText())  # https://stackoverflow.com/questions/24035660/how-to-read-from-qtextedit-in-python
        file.close()

        self.Widget.setWindowTitle(filename)

    def font_act (self):
        # https://stackoverflow.com/questions/54492063/why-does-qfontdialog-getfont-always-return-the-same-font
        fpf = QtWidgets.QFontDialog().getFont()[0]
        self.teBox.setFont(fpf)

    def bgcolor_act (self):
        # https://stackoverflow.com/questions/56024338/python-pyqt5-how-to-get-rgb-color-values-of-a-frame
        cpf = QtWidgets.QColorDialog().getColor().name()
        self.bgcolor = cpf
        self.teBox.setStyleSheet('background-color: '+self.bgcolor+";color: "+self.fgcolor)

    def fgcolor_act (self):
        # https://stackoverflow.com/questions/56024338/python-pyqt5-how-to-get-rgb-color-values-of-a-frame
        cpf = QtWidgets.QColorDialog().getColor().name()
        self.fgcolor = cpf
        self.teBox.setStyleSheet('background-color: '+self.bgcolor+";color: "+self.fgcolor)

==> pyabr-0.1.0-py3-none-any.whl: packs/baran/code/apps/barge/barge.py <==
from PyQt5 import QtWidgets, uic, QtGui,QtCore
import sys, importlib
from libabr import core,app as apps,res, file
from libnam import files
import app, importlib

class MainApp(QtWidgets.QMainWindow):
    filename = ''
    def __init__(self,args):
        super(MainApp, self).__init__()

        self.Backend = args[0]
        self.Env = args[1]
        self.Desktop = args[2]
        self.Widget = args[3]

        self.Widget.resize (700,500)

        self.Widget.setWindowTitle("Untitled - Barge")

        ## Set Icon ##
        self.Widget.setWindowIcon (QtGui.QIcon(res.get('@logo/barge')))
        ## Text Edit Configure ##

        ## Text Box ##
        self.teBox = QtWidgets.QTextEdit()
        self.statusbar = QtWidgets.QStatusBar()
        self.setCentralWidget(self.teBox)
        self.setStatusBar(self.statusbar)

        ## Menu Bar ##
        self.menubar = QtWidgets.QMenuBar()
        self.setMenuBar(self.menubar)

        # Menus #
        self.menu_file = self.menubar.addMenu(res.get('@string/menu_file'))

        # Actions #
        self.action_new = self.menu_file.addAction(res.get('@string/action_new'))
        self.action_new_page = self.menu_file.addAction(res.get('@string/action_new_page'))
        self.action_open = self.menu_file.addAction(res.get('@string/action_open'))
        self.action_save = self.menu_file.addAction(res.get('@string/action_save'))
        self.action_save_as = self.menu_file.addAction(res.get('@string/action_save_as'))
        self.action_exit = self.menu_file.addAction(res.get('@string/action_exit'))

        # Do actions ##
        self.action_new.triggered.connect(self.new_act)
        self.action_new_page.triggered.connect(self.new_page_act)
        self.action_open.triggered.connect(self.open_act)
        self.action_save.triggered.connect(self.save_act)
        self.action_save_as.triggered.connect(self.save_as_act)

        ## Set Default theme ##
        self.teBox.setFont(QtGui.QFont('Tahoma',12))
        self.bgcolor = '#FFFFFF'
        self.fgcolor = '#000000'
        self.teBox.setStyleSheet('background-color: ' + self.bgcolor + ";color: " + self.fgcolor)

    def new_act (self):
        self.teBox.clear()
        self.Widget.setWindowTitle(res.get("@string/new_barge"))


    def new_page_act (self):
        import barge
        self.Desktop.Run (barge)

    def open_act (self):
        apps.openbox(None)
        self.filename = files.readall("/proc/info/inp")

        if not self.filename=='':
            self.Widget.setWindowTitle(self.filename)

            strv = files.readall(self.filename)

            self.teBox.setText(strv)

    def save_act (self):
        if self.filename=='':
            apps.savebox(None)

            self.filename = files.readall('/proc/info/inp')

            files.write(self.filename, self.teBox.toPlainText())

            self.Widget.setWindowTitle(self.filename)
        else:
            files.write (self.filename,self.teBox.toPlainText())

    def save_as_act (self):
        apps.savebox(None)

        self.filename = files.readall('/proc/info/inp')

        files.write(self.filename, self.teBox.toPlainText())

        self.Widget.setWindowTitle(self.filename)
